image_dir="/var/lib/debci/qemu"
image="${image_dir}/${debci_suite}-${debci_arch}.img"
